@@ -1,21 +1,29 @@
-from typing import Optional
+from typing import Union, Optional
 
 
 class Profile:
-    def __init__(self, api):
-        """This class contains all API endpoints for the Profile category of the Retail World of Warcraft API
+    """This class contains all API endpoints for the Profile category of the
+    Retail World of Warcraft API
 
-        :param api: An instance of our generic API object
-        :type api: API
+    :param api: An instance of our generic API object
+    :type api: API
+    """
+
+    def __init__(self, api):
+        """Constructor method
         """
         self.api = api
 
-    async def get_profile_api_resource(self, namespace: str, endpoint: str, params: dict = None) -> Optional[dict]:
+    async def get_profile_api_resource(self,
+                                       namespace: str,
+                                       endpoint: str,
+                                       params: dict = None
+                                       ) -> Union[dict, None]:
         """Generic method for retrieving data from a Profile API endpoint
 
         :param namespace: The namespace of the resource we're trying to access
         :type namespace: str
-        :param endpoint: The API endpoint of the resource we're trying to access
+        :param endpoint: The endpoint of the resource we're trying to access
         :type endpoint: str
         :param params: Parameters to send with the request, defaults to None
         :type params: dict, optional
@@ -36,11 +44,14 @@ class Profile:
 
         return await self.api.get_resource(hostname, endpoint, params)
 
-    # region Character Achievements API
+# region Character Achievements API
 
-    async def get_character_achievements_summary(self, realm_slug: str, character_name: str):
+    async def get_character_achievements_summary(self,
+                                                 realm_slug: str,
+                                                 character_name: str
+                                                 ):
         """Returns a summary of the achievements a character has completed.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -51,11 +62,16 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/achievements"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_achievement_statistics(self, realm_slug: str, character_name: str):
+    async def get_character_achievement_statistics(self,
+                                                   realm_slug: str,
+                                                   character_name: str
+                                                   ):
         """Returns a character's statistics as they pertain to achievements.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -66,14 +82,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/achievements/statistics"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Appearance API
+# endregion
+# region Character Appearance API
 
-    async def get_character_appearance_summary(self, realm_slug: str, character_name: str):
+    async def get_character_appearance_summary(self,
+                                               realm_slug: str,
+                                               character_name: str
+                                               ):
         """Returns a summary of a character's appearance settings.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -84,14 +105,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/appearance"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Collections API
+# endregion
+# region Character Collections API
 
-    async def get_character_collections_index(self, realm_slug: str, character_name: str):
+    async def get_character_collections_index(self,
+                                              realm_slug: str,
+                                              character_name: str
+                                              ):
         """Returns an index of collection types for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -102,11 +128,16 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/collections"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_mounts_collection_summary(self, realm_slug: str, character_name: str):
+    async def get_character_mounts_collection_summary(self,
+                                                      realm_slug: str,
+                                                      character_name: str
+                                                      ):
         """Returns a summary of the mounts a character has obtained.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -117,11 +148,16 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/collections/mounts"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_pets_collection_summary(self, realm_slug: str, character_name: str):
+    async def get_character_pets_collection_summary(self,
+                                                    realm_slug: str,
+                                                    character_name: str
+                                                    ):
         """Returns a summary of the battle pets a character has obtained.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -132,14 +168,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/collections/pets"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Encounters API
+# endregion
+# region Character Encounters API
 
-    async def get_character_encounters_summary(self, realm_slug: str, character_name: str):
+    async def get_character_encounters_summary(self,
+                                               realm_slug: str,
+                                               character_name: str
+                                               ):
         """Returns a summary of a character's encounters.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -150,11 +191,16 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/encounters"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_dungeons(self, realm_slug: str, character_name: str):
+    async def get_character_dungeons(self,
+                                     realm_slug: str,
+                                     character_name: str
+                                     ):
         """Returns a summary of a character's completed dungeons.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -165,11 +211,16 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/encounters/dungeons"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_raids(self, realm_slug: str, character_name: str):
+    async def get_character_raids(self,
+                                  realm_slug: str,
+                                  character_name: str
+                                  ):
         """Returns a summary of a character's completed raids.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -180,14 +231,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/encounters/raids"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Equipment API
+# endregion
+# region Character Equipment API
 
-    async def get_character_equipment_summary(self, realm_slug: str, character_name: str):
+    async def get_character_equipment_summary(self,
+                                              realm_slug: str,
+                                              character_name: str
+                                              ):
         """Returns a summary of the items equipped by a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -198,14 +254,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/equipment"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Hunter Pets API
+# endregion
+# region Character Hunter Pets API
 
-    async def get_character_hunter_pets_summary(self, realm_slug: str, character_name: str):
+    async def get_character_hunter_pets_summary(self,
+                                                realm_slug: str,
+                                                character_name: str
+                                                ):
         """If the character is a hunter, returns a summary of the character's hunter pets. Otherwise, returns an HTTP 404 Not Found error.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -216,14 +277,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/hunter-pets"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Media API
+# endregion
+# region Character Media API
 
-    async def get_character_media_summary(self, realm_slug: str, character_name: str):
+    async def get_character_media_summary(self,
+                                          realm_slug: str,
+                                          character_name: str
+                                          ):
         """Returns a summary of the media assets available for a character (such as an avatar render).
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -234,14 +300,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/character-media"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Mythic Keystone Profile API
+# endregion
+# region Character Mythic Keystone Profile API
 
-    async def get_character_mythic_keystone_profile_index(self, realm_slug: str, character_name: str):
+    async def get_character_mythic_keystone_profile_index(self,
+                                                          realm_slug: str,
+                                                          character_name: str
+                                                          ):
         """Returns the Mythic Keystone profile index for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -252,13 +323,19 @@ class Profile:
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/mythic-keystone-profile"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_mythic_keystone_season_details(self, realm_slug: str, character_name: str, season_id: str):
+    async def get_character_mythic_keystone_season_details(self,
+                                                           realm_slug: str,
+                                                           character_name: str,
+                                                           season_id: str
+                                                           ):
         """Returns the Mythic Keystone season details for a character.
 
 Returns a 404 Not Found for characters that have not yet completed a Mythic Keystone dungeon for the specified season.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -271,14 +348,19 @@ Returns a 404 Not Found for characters that have not yet completed a Mythic Keys
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/mythic-keystone-profile/season/{season_id}"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Professions API
+# endregion
+# region Character Professions API
 
-    async def get_character_professions_summary(self, realm_slug: str, character_name: str):
+    async def get_character_professions_summary(self,
+                                                realm_slug: str,
+                                                character_name: str
+                                                ):
         """Returns a summary of professions for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -289,14 +371,19 @@ Returns a 404 Not Found for characters that have not yet completed a Mythic Keys
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/professions"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Profile API
+# endregion
+# region Character Profile API
 
-    async def get_character_profile_summary(self, realm_slug: str, character_name: str):
+    async def get_character_profile_summary(self,
+                                            realm_slug: str,
+                                            character_name: str
+                                            ):
         """Returns a profile summary for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -307,9 +394,14 @@ Returns a 404 Not Found for characters that have not yet completed a Mythic Keys
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_profile_status(self, realm_slug: str, character_name: str):
+    async def get_character_profile_status(self,
+                                           realm_slug: str,
+                                           character_name: str
+                                           ):
         """Returns the status and a unique ID for a character. A client should delete information about a character from their application if any of the following conditions occur:
 an HTTP 404 Not Found error is returned
 the is_valid value is false
@@ -319,7 +411,7 @@ A client requests and stores information about a character, including its unique
 After 30 days, the client makes a request to the status endpoint to verify if the character information is still valid.
 If character cannot be found, is not valid, or the characters IDs do not match, the client removes the information from their application.
 If the character is valid and the character IDs match, the client retains the data for another 30 days.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -330,14 +422,20 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/status"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character PvP API
+# endregion
+# region Character PvP API
 
-    async def get_character_pvp_bracket_statistics(self, realm_slug: str, character_name: str, pvp_bracket: str):
+    async def get_character_pvp_bracket_statistics(self,
+                                                   realm_slug: str,
+                                                   character_name: str,
+                                                   pvp_bracket: str
+                                                   ):
         """Returns the PvP bracket statistics for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -350,11 +448,16 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/pvp-bracket/{pvp_bracket}"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_pvp_summary(self, realm_slug: str, character_name: str):
+    async def get_character_pvp_summary(self,
+                                        realm_slug: str,
+                                        character_name: str
+                                        ):
         """Returns a PvP summary for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -365,14 +468,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/pvp-summary"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Quests API
+# endregion
+# region Character Quests API
 
-    async def get_character_quests(self, realm_slug: str, character_name: str):
+    async def get_character_quests(self,
+                                   realm_slug: str,
+                                   character_name: str
+                                   ):
         """Returns a character's active quests as well as a link to the character's completed quests.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -383,11 +491,16 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/quests"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_character_completed_quests(self, realm_slug: str, character_name: str):
+    async def get_character_completed_quests(self,
+                                             realm_slug: str,
+                                             character_name: str
+                                             ):
         """Returns a list of quests that a character has completed.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -398,14 +511,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/quests/completed"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Reputations API
+# endregion
+# region Character Reputations API
 
-    async def get_character_reputations_summary(self, realm_slug: str, character_name: str):
+    async def get_character_reputations_summary(self,
+                                                realm_slug: str,
+                                                character_name: str
+                                                ):
         """Returns a summary of a character's reputations.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -416,14 +534,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/reputations"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Soulbinds API
+# endregion
+# region Character Soulbinds API
 
-    async def get_character_soulbinds(self, realm_slug: str, character_name: str):
+    async def get_character_soulbinds(self,
+                                      realm_slug: str,
+                                      character_name: str
+                                      ):
         """Returns a character's soulbinds.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -434,14 +557,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/soulbinds"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Specializations API
+# endregion
+# region Character Specializations API
 
-    async def get_character_specializations_summary(self, realm_slug: str, character_name: str):
+    async def get_character_specializations_summary(self,
+                                                    realm_slug: str,
+                                                    character_name: str
+                                                    ):
         """Returns a summary of a character's specializations.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -452,14 +580,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/specializations"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Statistics API
+# endregion
+# region Character Statistics API
 
-    async def get_character_statistics_summary(self, realm_slug: str, character_name: str):
+    async def get_character_statistics_summary(self,
+                                               realm_slug: str,
+                                               character_name: str
+                                               ):
         """Returns a statistics summary for a character.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -470,14 +603,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/statistics"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Character Titles API
+# endregion
+# region Character Titles API
 
-    async def get_character_titles_summary(self, realm_slug: str, character_name: str):
+    async def get_character_titles_summary(self,
+                                           realm_slug: str,
+                                           character_name: str
+                                           ):
         """Returns a summary of titles a character has obtained.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param character_name: The lowercase name of the character.
@@ -488,14 +626,19 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/profile/wow/character/{realm_slug}/{character_name}/titles"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
-    # region Guild API
+# endregion
+# region Guild API
 
-    async def get_guild(self, realm_slug: str, name_slug: str):
+    async def get_guild(self,
+                        realm_slug: str,
+                        name_slug: str
+                        ):
         """Returns a single guild by its name and realm.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param name_slug: The slug of the guild.
@@ -506,11 +649,16 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/data/wow/guild/{realm_slug}/{name_slug}"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_guild_activity(self, realm_slug: str, name_slug: str):
+    async def get_guild_activity(self,
+                                 realm_slug: str,
+                                 name_slug: str
+                                 ):
         """Returns a single guild's activity by name and realm.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param name_slug: The slug of the guild.
@@ -521,11 +669,16 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/data/wow/guild/{realm_slug}/{name_slug}/activity"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_guild_achievements(self, realm_slug: str, name_slug: str):
+    async def get_guild_achievements(self,
+                                     realm_slug: str,
+                                     name_slug: str
+                                     ):
         """Returns a single guild's achievements by name and realm.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param name_slug: The slug of the guild.
@@ -536,11 +689,16 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/data/wow/guild/{realm_slug}/{name_slug}/achievements"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    async def get_guild_roster(self, realm_slug: str, name_slug: str):
+    async def get_guild_roster(self,
+                               realm_slug: str,
+                               name_slug: str
+                               ):
         """Returns a single guild's roster by its name and realm.
-
+        
         :param realm_slug: The slug of the realm.
         :type realm_slug: str
         :param name_slug: The slug of the guild.
@@ -551,6 +709,8 @@ If the character is valid and the character IDs match, the client retains the da
         endpoint = f"/data/wow/guild/{realm_slug}/{name_slug}/roster"
         namespace = "profile-{region}"
 
-        return await self.get_profile_api_resource(namespace, endpoint)
+        return await self.get_profile_api_resource(
+                                                   namespace, 
+                                                   endpoint)
 
-    # endregion
+# endregion
